==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/th/mail.php <==
<?php

return array(
    'a_user_canceled' => 'ผู้ใช้ยกเลิกคำร้องขอสินค้าในเว็บไซต์แล้ว',
    'a_user_requested' => 'ผู้ใช้ร้องขอรายการบนเว็บไซต์',
    'accessory_name' => 'ชื่ออุปกรณ์เสริม:',
    'additional_notes' => 'หมายเหตุเพิ่มเติม:',
    'admin_has_created' => 'ผู้ดูแลระบบได้สร้างบัญชีให้กับคุณบนเว็บไซต์: web',
    'asset' => 'ทรัพย์สิน:',
    'asset_name' => 'ชื่อสินทรัพย์:',
    'asset_requested' => 'สินทรัพย์ที่ขอ',
    'asset_tag' => 'แท็กเนื้อหา:',
    'assigned_to' => 'ได้รับมอบหมายให้',
    'best_regards' => 'ด้วยความเคารพ,',
    'canceled' => 'ยกเลิก:',
    'checkin_date' => 'วันที่เช็คอิน:',
    'checkout_date' => 'วันที่ชำระเงิน:',
    'click_to_confirm' => 'โปรดคลิกลิงก์ต่อไปนี้เพื่อยืนยันข้อมูล: บัญชีเว็บ:',
    'click_on_the_link_accessory' => 'โปรดคลิกที่ลิงค์ด้านล่างเพื่อยืนยันว่าคุณได้รับอุปกรณ์เสริมแล้ว',
    'click_on_the_link_asset' => 'โปรดคลิกลิงก์ที่ด้านล่างเพื่อยืนยันว่าคุณได้รับเนื้อหาแล้ว',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'QTY ปัจจุบัน',
    'Days' => 'วัน',
    'days' => 'วัน',
    'expecting_checkin_date' => 'คาดว่าวันที่เช็คอิน:',
    'expires' => 'วันที่หมดอายุ',
    'Expiring_Assets_Report' => 'รายงานสินทรัพย์หมดอายุ',
    'Expiring_Licenses_Report' => 'รายงานใบอนุญาตหมดอายุ',
    'hello' => 'สวัสดี',
    'hi' => 'สวัสดี',
    'i_have_read' => 'ฉันได้อ่านและยอมรับข้อกำหนดในการให้บริการแล้วและได้รับสินค้านี้แล้ว',
    'item' => 'รายการ:',
    'Item_Request_Canceled' => 'ขอรายการถูกยกเลิกแล้ว',
    'Item_Requested' => 'รายการที่ขอ',
    'link_to_update_password' => 'โปรดคลิกลิงก์ต่อไปนี้เพื่ออัปเดต: รหัสผ่านเว็บ:',
    'login_first_admin' => 'เข้าสู่ระบบการติดตั้ง Snipe-IT ใหม่ของคุณโดยใช้ข้อมูลรับรองด้านล่าง:',
    'login' => 'เข้าสู่ระบบ:',
    'Low_Inventory_Report' => 'รายงานพื้นที่โฆษณาต่ำ',
    'min_QTY' => 'Min QTY',
    'name' => 'ชื่อ',
    'new_item_checked' => 'รายการใหม่ได้รับการตรวจสอบภายใต้ชื่อของคุณแล้วรายละเอียดมีดังนี้',
    'password' => 'รหัสผ่าน:',
    'password_reset' => 'รีเซ็ตรหัสผ่าน',

    'read_the_terms' => 'โปรดอ่านเงื่อนไขการใช้งานด้านล่างนี้',
    'read_the_terms_and_click' => 'โปรดอ่านเงื่อนไขการใช้ด้านล่างและคลิกลิงก์ด้านล่างเพื่อยืนยันว่าคุณอ่านและยอมรับข้อกำหนดในการให้บริการและได้รับเนื้อหาแล้ว',
    'requested' => 'ขอ:',
    'reset_link' => 'ลิงก์รีเซ็ตรหัสผ่านของคุณ',
    'reset_password' => 'คลิกที่นี่เพื่อรีเซ็ตรหัสผ่าน:',
    'serial' => 'หมายเลขผลิตภัณฑ์',
    'supplier' => 'ผู้ผลิต',
    'tag' => 'แท็ก',
    'test_email' => 'ทดสอบอีเมลจาก Snipe-IT',
    'test_mail_text' => 'นี่เป็นการทดสอบจาก Snipe-IT Asset Management System ถ้าคุณได้รับอีเมลนี้จะทำงาน :)',
    'the_following_item' => 'รายการต่อไปนี้ได้รับการตรวจสอบใน:',
    'low_inventory_alert' => 'มี: นับสินค้าที่ต่ำกว่าสินค้าคงคลังขั้นต่ำหรือเร็ว ๆ นี้จะต่ำ|มี: นับสินค้าที่ต่ำกว่าสินค้าคงคลังขั้นต่ำหรือจะเร็วเกินไป',
    'assets_warrantee_alert' => 'มี: จำนวนสินทรัพย์ที่สิ้นสุดระยะรับประกันในถัดไป: เกณฑ์วัน|มี: นับสินทรัพย์ที่จะสิ้นสุดระยะประกันในถัดไป: เกณฑ์วัน',
    'license_expiring_alert' => 'มี: ใบอนุญาตที่จะหมดอายุในวันถัดไป: วันที่กำหนด|มี: ใบอนุญาตที่จะหมดอายุในวันถัดไป: วันที่กำหนด',
    'to_reset' => 'ในการรีเซ็ตรหัสผ่านเว็บของคุณโปรดกรอกแบบฟอร์มนี้:',
    'type' => 'ชนิด',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'ผู้ใช้งาน',
    'username' => 'ชื่อผู้ใช้',
    'welcome' => 'ยินดีต้อนรับ: ชื่อ',
    'welcome_to' => 'ยินดีต้อนรับสู่: web!',
    'your_credentials' => 'ข้อมูลรับรอง Snipe-IT ของคุณ',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/th/mail.php <==
<?php

return [
    'a_user_canceled' => 'ผู้ใช้ยกเลิกคำร้องขอสินค้าในเว็บไซต์แล้ว',
    'a_user_requested' => 'ผู้ใช้ร้องขอรายการบนเว็บไซต์',
    'accessory_name' => 'ชื่ออุปกรณ์เสริม:',
    'additional_notes' => 'หมายเหตุเพิ่มเติม:',
    'admin_has_created' => 'ผู้ดูแลระบบได้สร้างบัญชีให้กับคุณบนเว็บไซต์: web',
    'asset' => 'ทรัพย์สิน:',
    'asset_name' => 'ชื่อสินทรัพย์:',
    'asset_requested' => 'สินทรัพย์ที่ขอ',
    'asset_tag' => 'แท็กทรัพย์สิน',
    'assigned_to' => 'ได้รับมอบหมายให้',
    'best_regards' => 'ด้วยความเคารพ,',
    'canceled' => 'ยกเลิก:',
    'checkin_date' => 'วันที่เช็คอิน:',
    'checkout_date' => 'วันที่ชำระเงิน:',
    'click_to_confirm' => 'โปรดคลิกลิงก์ต่อไปนี้เพื่อยืนยันข้อมูล: บัญชีเว็บ:',
    'click_on_the_link_accessory' => 'โปรดคลิกที่ลิงค์ด้านล่างเพื่อยืนยันว่าคุณได้รับอุปกรณ์เสริมแล้ว',
    'click_on_the_link_asset' => 'โปรดคลิกลิงก์ที่ด้านล่างเพื่อยืนยันว่าคุณได้รับเนื้อหาแล้ว',
    'Confirm_Asset_Checkin' => 'ยืนยันการเช็คอินสินทรัพย์',
    'Confirm_Accessory_Checkin' => 'ยืนยันการเช็คอินอุปกรณ์เสริม',
    'Confirm_accessory_delivery' => 'ยืนยันการจัดส่งอุปกรณ์เสริม',
    'Confirm_license_delivery' => 'การยืนยันการส่งมอบใบอนุญาต',
    'Confirm_asset_delivery' => 'ยืนยันการจัดส่งสินทรัพย์',
    'Confirm_consumable_delivery' => 'ยืนยันการจัดส่งวัสดุสิ้นเปลือง',
    'current_QTY' => 'QTY ปัจจุบัน',
    'Days' => 'วัน',
    'days' => 'วัน',
    'expecting_checkin_date' => 'คาดว่าวันที่เช็คอิน:',
    'expires' => 'วันที่หมดอายุ',
    'Expiring_Assets_Report' => 'รายงานสินทรัพย์หมดอายุ',
    'Expiring_Licenses_Report' => 'รายงานใบอนุญาตหมดอายุ',
    'hello' => 'สวัสดี',
    'hi' => 'สวัสดี',
    'i_have_read' => 'ฉันได้อ่านและยอมรับข้อกำหนดในการให้บริการแล้วและได้รับสินค้านี้แล้ว',
    'item' => 'รายการ:',
    'Item_Request_Canceled' => 'ขอรายการถูกยกเลิกแล้ว',
    'Item_Requested' => 'รายการที่ขอ',
    'link_to_update_password' => 'โปรดคลิกลิงก์ต่อไปนี้เพื่ออัปเดต: รหัสผ่านเว็บ:',
    'login_first_admin' => 'เข้าสู่ระบบการติดตั้ง Snipe-IT ใหม่ของคุณโดยใช้ข้อมูลรับรองด้านล่าง:',
    'login' => 'เข้าสู่ระบบ:',
    'Low_Inventory_Report' => 'รายงานพื้นที่โฆษณาต่ำ',
    'min_QTY' => 'Min QTY',
    'name' => 'ชื่อ',
    'new_item_checked' => 'รายการใหม่ได้รับการตรวจสอบภายใต้ชื่อของคุณแล้วรายละเอียดมีดังนี้',
    'password' => 'รหัสผ่าน:',
    'password_reset' => 'รีเซ็ตรหัสผ่าน',

    'read_the_terms' => 'โปรดอ่านเงื่อนไขการใช้งานด้านล่างนี้',
    'read_the_terms_and_click' => 'โปรดอ่านเงื่อนไขการใช้ด้านล่างและคลิกลิงก์ด้านล่างเพื่อยืนยันว่าคุณอ่านและยอมรับข้อกำหนดในการให้บริการและได้รับเนื้อหาแล้ว',
    'requested' => 'ขอ:',
    'reset_link' => 'ลิงก์รีเซ็ตรหัสผ่านของคุณ',
    'reset_password' => 'คลิกที่นี่เพื่อรีเซ็ตรหัสผ่าน:',
    'serial' => 'หมายเลขผลิตภัณฑ์',
    'supplier' => 'ผู้ผลิต',
    'tag' => 'แท็ก',
    'test_email' => 'ทดสอบอีเมลจาก Snipe-IT',
    'test_mail_text' => 'นี่เป็นการทดสอบจาก Snipe-IT Asset Management System ถ้าคุณได้รับอีเมลนี้จะทำงาน :)',
    'the_following_item' => 'รายการต่อไปนี้ได้รับการตรวจสอบใน:',
    'low_inventory_alert' => 'มี: นับสินค้าที่ต่ำกว่าสินค้าคงคลังขั้นต่ำหรือเร็ว ๆ นี้จะต่ำ|มี: นับสินค้าที่ต่ำกว่าสินค้าคงคลังขั้นต่ำหรือจะเร็วเกินไป',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'มี: ใบอนุญาตที่จะหมดอายุในวันถัดไป: วันที่กำหนด|มี: ใบอนุญาตที่จะหมดอายุในวันถัดไป: วันที่กำหนด',
    'to_reset' => 'ในการรีเซ็ตรหัสผ่านเว็บของคุณโปรดกรอกแบบฟอร์มนี้:',
    'type' => 'ชนิด',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'ผู้ใช้งาน',
    'username' => 'ชื่อผู้ใช้',
    'welcome' => 'ยินดีต้อนรับ: ชื่อ',
    'welcome_to' => 'ยินดีต้อนรับสู่: web!',
    'your_credentials' => 'ข้อมูลรับรอง Snipe-IT ของคุณ',
    'Accessory_Checkin_Notification' => 'เช็คอินอุปกรณ์เสริมแล้ว',
    'Asset_Checkin_Notification' => 'เช็คอินสินทรัพย์แล้ว',
    'License_Checkin_Notification' => 'เช็คอินใบอนุญาตแล้ว',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'เตือนความจำ :: ใกล้หมดเวลาเช็คอิน',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'ดูสินทรัพย์ที่มี',
];
